@@ -5,14 +5,18 @@ import (
 	"github.com/alecthomas/chroma/lexers/internal"
 )
 
-var TOML = internal.Register(MustNewLexer(
+var TOML = internal.Register(MustNewLazyLexer(
 	&Config{
 		Name:      "TOML",
 		Aliases:   []string{"toml"},
 		Filenames: []string{"*.toml"},
 		MimeTypes: []string{"text/x-toml"},
 	},
-	Rules{
+	tomlRules,
+))
+
+func tomlRules() Rules {
+	return Rules{
 		"root": {
 			{`\s+`, Text, nil},
 			{`#.*`, Comment, nil},
@@ -25,5 +29,5 @@ var TOML = internal.Register(MustNewLexer(
 			{`[.,=\[\]{}]`, Punctuation, nil},
 			{`[^\W\d]\w*`, NameOther, nil},
 		},
-	},
-))
+	}
+}
